# Gender Classification using CNN

This project is aimed at real-time face detection with gender classification using Convolutional Neural Networks (CNNs) with the help of OpenCV (Python). It offers a simple and accurate solution for detecting gender from images, contributing to the development of gender detection systems in the digital era.

## Contents

1. [About](#about)
2. [Files](#files)
3. [Training](#training)
4. [Testing](#testing)
5. [Dependencies](#dependencies)
6. [Project Trailer](#project-trailer)
7. [Author](#author)

## About

The Gender Classification using CNN project implements real-time face detection and gender classification using CNNs. With the trained model, the system can accurately classify the gender of individuals captured by a camera in real-time. It leverages the power of deep learning to achieve high accuracy and efficiency in gender detection tasks.

## Files

1. **Dataset**: The dataset used for training the gender classification model.
2. **Gender_Classification_model_2.h5**: Pre-trained model weights saved in HDF5 format.
3. **Training.ipynb**: Jupyter Notebook containing the Python code for training the CNN model.
4. **Testing.ipynb**: Jupyter Notebook containing the Python code for testing the trained model in real-time.
5. **haarcascade_frontalface_default.xml**: XML file containing the pre-trained Haar Cascade classifier for face detection.
6. **README.md**: This file, providing an overview of the project.

## Training

The `Training.ipynb` notebook contains the code for training the CNN model using the provided dataset. It includes data preprocessing, model architecture definition, training process configuration, and model evaluation.

## Testing

The `Testing.ipynb` notebook demonstrates how to use the trained model for real-time gender classification. It utilizes OpenCV for face detection and the trained CNN model for gender classification. The system captures video input from a camera and overlays gender labels on detected faces in real-time.

## Dependencies

This project requires the following dependencies:

- Python 3.x
- TensorFlow
- Keras
- NumPy
- Matplotlib
- OpenCV
- Jupyter Notebook

You can install these dependencies using pip:

```bash
pip install tensorflow keras numpy matplotlib opencv-python jupyter
```

## Project Trailer

- [Project Trailer](https://www.youtube.com/watch?v=nIurZm2oCs8) <br> <br>
  [![Gender-Classification-using-CNN](https://img.youtube.com/vi/nIurZm2oCs8/0.jpg)](https://www.youtube.com/watch?v=nIurZm2oCs8)

## Author

Gulam Kibria Chowdhury<br>
Software Developer || Competitive Programmer<br>
Sylhet, Bangladesh<br>
Gmail: gkchowdhury101@gmail.com<br>
